@@ -212,6 +212,61 @@ occ_count <- function(...,occurrenceStatus="PRESENT", curlopts = list()) {
              lifeStage = args$lifeStage,
              isInCluster = args$isInCluster,
              distanceFromCentroidInMeters = args$distanceFromCentroidInMeters,
+             geoDistance = args$geoDistance,
+             sex = args$sex,
+             dwcaExtension = args$dwcaExtension,
+             gbifId = args$gbifId,
+             gbifRegion = args$gbifRegion,
+             projectId = args$projectId,
+             programme = args$programme,
+             preparations = args$preparations,
+             datasetId = args$datsetId,
+             datasetName = args$datasetName,
+             publishedByGbifRegion = args$publishedByGbifRegion,
+             island = args$island,
+             islandGroup = args$islandGroup,
+             taxonId = args$taxonId,
+             taxonConceptId = args$taxonConceptId,
+             taxonomicStatus = args$taxonomicStatus,
+             acceptedTaxonKey = args$acceptedTaxonKey,
+             collectionKey = args$collectionsKey,
+             institutionKey = args$institutionKey,
+             otherCatalogNumbers = args$otherCatalogNumbers,
+             georeferencedBy = args$georeferencedBy,
+             installationKey = args$installationKey,
+             hostingOrganizationKey = args$hostingOrganizationKey,
+             crawlId = args$crawlId,
+             modified = args$modified,
+             higherGeography = args$higherGeography,
+             fieldNumber = args$fieldNumber,
+             parentEventId = args$parentEventId,
+             samplingProtocol = args$samplingProtocol,
+             sampleSizeUnit = args$sampleSizeUnit,
+             pathway = args$pathway,
+             gadmLevel0Gid = args$gadmLevel0Gid,
+             gadmLevel1Gid = args$gadmLevel1Gid,
+             gadmLevel2Gid = args$gadmLevel2Gid,
+             gadmLevel3Gid = args$gadmLevel3Gid,
+             earliestEonOrLowestEonothem = args$earliestEonOrLowestEonothem,
+             latestEonOrHighestEonothem = args$latestEonOrHighestEonothem,
+             earliestEraOrLowestErathem = args$earliestEraOrLowestErathem,
+             latestEraOrHighestErathem = args$latestEraOrHighestErathem,
+             earliestPeriodOrLowestSystem = args$earliestPeriodOrLowestSystem,
+             latestPeriodOrHighestSystem = args$latestPeriodOrHighestSystem,
+             earliestEpochOrLowestSeries = args$earliestEpochOrLowestSeries,
+             latestEpochOrHighestSeries = args$latestEpochOrHighestSeries,
+             earliestAgeOrLowestStage = args$earliestAgeOrLowestStage,
+             latestAgeOrHighestStage = args$latestAgeOrHighestStage,
+             lowestBiostratigraphicZone = args$lowestBiostratigraphicZone,
+             highestBiostratigraphicZone = args$highestBiostratigraphicZone,
+             group = args$group,
+             formation = args$formation,
+             member = args$member,
+             bed = args$bed,
+             associatedSequences = args$aassociatedSequences,
+             isSequenced = args$isSequenced,
+             startDayOfYear = args$startDayOfYear,
+             endDayOfYear = args$endDayOfYear,
              limit=0,
              start=0,
              fields = 'all',
@@ -224,10 +279,23 @@ occ_count <- function(...,occurrenceStatus="PRESENT", curlopts = list()) {
              facetLimit = args$facetLimit)
  
  if("facet" %in% arg_names) {
-      not_facet_arg <- c("skip_validate","...","curlopts","facetMultiselect",
-                         "facetMincount", "facet","return","fields","start",
-                         "limit","verbatimTaxonId","geometry", "geom_big",
-                         "geom_size","geom_n","search")
+      not_facet_arg <- c("skip_validate",
+                         "...",
+                         "curlopts",
+                         "facetMultiselect",
+                         "facetMincount", 
+                         "facet",
+                         "return",
+                         "fields",
+                         "start",
+                         "limit",
+                         "verbatimTaxonId",
+                         "geometry",
+                         "geom_big",
+                         "geom_size",
+                         "geom_n",
+                         "search",
+                         "geoDistance")
       acc_facet_arg <- formal_args[!formal_args %in% not_facet_arg]
    if(!args$facet %in% acc_facet_arg) stop("Bad facet arg.")
    count <- stats::setNames(res$facet[[1]],c(args$facet,"count"))
